# Create an agent

## Create a new agent
It is recommended to have a dedicated directory for each agent. In your agent directory, run:

```bash
mur new agent my-awesome-agent
```

This will create a `murmur-build.yaml` file. Fill out the details of your agent and save the file.

## Buid your agent
Run the following command to build your agent:

```bash
mur build
```

## Publish an agent

## Install an agent

